# marine-omics
[![Python Version](https://img.shields.io/pypi/pyversions/momics.svg?color=green)](https://python.org)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![tests](https://github.com/palec87/marine-omics/workflows/tests/badge.svg)](https://github.com/palec87/marine-omics/actions)
[![codecov](https://codecov.io/gh/emo-bon/marine-omics-methods/branch/main/graph/badge.svg)](https://codecov.io/gh/emo-bon/marine-omics-methods)
[![Read the Docs](https://img.shields.io/readthedocs/marine-omics)](https://marine-omics-methods.readthedocs.io/en/latest/)

Package of utilities for FAIR-Ease demo pipelines.

These methods are currently use only for FAIR-EASE [pilot demos](https://github.com/palec87/momics-demos), but eventually they can serve for general purpose manipulation of metagenomic data, locally and in some VREs.

The idea is to provide testable methods to allow as much flexibility and remixing the functionalities provided

## Python
`panel` dashboard support for specific use cases by building the the app widgets. No attempts are planned to make most of the methods general purpose, but feel free to open PRs.
`Galaxy` support. OOP wrapper around [bioblend](https://bioblend.readthedocs.io/en/latest/). This is probably not the best approach to hide bioblend 


## R
TBA

## Julia
TBA
